@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Patch.py 12806 2021-03-24 05:59:30Z Casey $
+# $Id: Patch.py 12973 2021-06-13 11:56:03Z Becca $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Casey $ (last)
-# $Date: 2021-03-24 13:59:30 +0800 (週三, 24 三月 2021) $
-# $Revision: 12806 $
+# $Author: Becca $ (last)
+# $Date: 2021-06-13 19:56:03 +0800 (Sun, 13 Jun 2021) $
+# $Revision: 12973 $
 #
 # Contributors:
 #  Bear
@@ -51,34 +51,6 @@ def attachDebugSettings(settingsDict):
     else:
         extendInstalledApps(settingsDict, ('django_extensions',))
 
-    # debug tool bar
-    try:
-        import debug_toolbar
-    except ImportError:
-        warnings.warn(
-            colored(
-                "Can't import debug_toolbar."
-                " Please install django-debug-toolbar==1.9.1.",
-                'yellow', attrs=['bold']
-            )
-        )
-    else:
-        if settingsDict.get('DEBUG_TOOLBAR_ENABLE', None):
-            extendInstalledApps(settingsDict, ('debug_toolbar',))
-            extendMiddlewareClasses(
-                settingsDict,
-                ("debug_toolbar.middleware.DebugToolbarMiddleware",)
-            )
-
-            toolbarSettings = {
-                'INTERNAL_IPS': ['127.0.0.1'],
-            }
-            update(settingsDict, toolbarSettings)
-
-            populateEnvToSettings((
-                'INTERNAL_IPS',
-            ), settingsDict)
-
 def extendSettings(settingsLocals):
     """
     Extend settings.
